@@ -10,7 +10,7 @@
 #   IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 #   WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #
-#   $Id: FQDN_IPAddr.pm 294756 2005-08-07 00:03:03Z richter $
+#   $Id: FQDN_IPAddr.pm 410198 2006-05-30 06:49:55Z richter $
 #
 ###################################################################################
 
@@ -26,6 +26,11 @@ my %error_messages =
 	validate_fqdn_ipaddr => 'Feld %0: "%1" ist keine gltiger Hostname oder IP-Adresse.',
     },
 
+    'de.utf-8' => 
+    {
+	validate_fqdn_ipaddr => 'Feld %0: "%1" ist keine gültiger Hostname oder IP-Adresse.',
+    },
+
     en =>
     {
 	validate_fqdn_ipaddr => 'Field %0: "%1" isn\\\'t a valid hostname or ip-address.',
